// =============================================================================
// Command.h: Declarations of class cCommand
// Filter application, (c) lars.staurset@statkart.no 2003
// Purpose: Base for all command classes
// =============================================================================

#pragma once
#include "Typedefs.h"
#include "InStream.h"
#include "OutStream.h"

class cCommand
{
    // =========================================================================
    // Public functions
    // =========================================================================
public:
    // ---------------------------------------------------------------------------
    // Class administration (construction, destruction, etc.)
    // ---------------------------------------------------------------------------
    // Constructor
    // Success: Input and output streams are opened and ready for use
    // Failure: Throws a cException
    cCommand (
        const string,           // Path of input stream
        const string,           // Path of output stream
        const bool,             // true if overwriting is allowed
        const OutputLevel);     // Output level, see Typedefs.h

    virtual ~cCommand(void);

    // ---------------------------------------------------------------------------
    // Data processing
    // ---------------------------------------------------------------------------
    // Do the job
    // Success: Job was done
    // Failure: returns false
    virtual bool Execute ();    // return true if successful

    // =========================================================================
    // Protected data members
    // =========================================================================
protected:
    // ---------------------------------------------------------------------------
    // Members passed from client class
    // ---------------------------------------------------------------------------
    string m_sInStream;         // Path of input stream
    string m_sOutStream;        // Path of output stream
    OutputLevel m_eOutputLevel;    // Output level, see Typedefs.h

    // ---------------------------------------------------------------------------
    // Members proper to this class
    // ---------------------------------------------------------------------------
    cInStream *m_pInStream;     // Instream object
    cOutStream *m_pOutStream;   // Outstream object
};
