// =============================================================================
// InStream.cpp: Implementation of class cInStream
// Filter application, (c) lars.staurset@statkart.no 2003
// =============================================================================

#include <iostream>
#include "InStream.h"
#include "Exception.h"

// =========================================================================
// Public functions
// =========================================================================

// ---------------------------------------------------------------------------
// Class administration (construction, destruction, etc.)
// ---------------------------------------------------------------------------
// Constructor
cInStream::cInStream (const string csInStream, const OutputLevel ceOutputLevel)
{
    // Store parameters
    m_eOutputLevel = ceOutputLevel;

    // Initialize private data members
    m_pStream = new ifstream (csInStream.data());
    if (!m_pStream)
        throw cException ("Unable to create instream object");
    if (m_eOutputLevel >= OL_Debug)
        cout << "cInStream::cInStream: bad=" << m_pStream->bad() << " fail=" << m_pStream->fail() << " eof=" << m_pStream->eof() << " good=" << m_pStream->good() << endl;
    if (m_pStream->fail()) {
        delete m_pStream;
        m_pStream = NULL;
        throw cException ("Unable to open input file \'" + csInStream + "\'");
    }
    m_nLineCount = 0;
}

// Destructor
cInStream::~cInStream(void)
{
   if (m_pStream) {
      m_pStream->close();
      delete m_pStream;
   }
}

// ---------------------------------------------------------------------------
// Data processing
// ---------------------------------------------------------------------------
// Read a line
bool cInStream::ReadLine (string *ps)
{
    getline (*m_pStream, *ps, '\n');

    // End of file?
    if (m_pStream->eof())
        return false;
    m_nLineCount++;

    // Read error?
    if (m_pStream->fail())
        throw cException ("Read error in line # %d", m_nLineCount);

    // Normal line
    if (m_eOutputLevel == OL_Dump)
        cout << "cInStream::ReadLine# " <<  m_nLineCount << ".\'" << *ps << "\'\n";
    return true;
}
