// =============================================================================
// OutStream.cpp: Implementation of class cOutStream
// Filter application, (c) lars.staurset@statkart.no 2003
// =============================================================================

#include <iostream>
#include "OutStream.h"
#include "Exception.h"

// =========================================================================
// Public functions
// =========================================================================

// ---------------------------------------------------------------------------
// Class administration (construction, destruction, etc.)
// ---------------------------------------------------------------------------
// Constructor
cOutStream::cOutStream (const string csOutStream, const bool cbAllowOverwrite,
                        const OutputLevel ceOutputLevel)
{
    // Store parameters
    m_eOutputLevel = ceOutputLevel;

    // Is is allowed to overwrite the output file?
    if (!cbAllowOverwrite) {
        // No, try to open for reading to check if file exists
        ifstream *pStream = new ifstream (csOutStream.data());
        if (!pStream)
            throw cException ("Unable to create stream object");
        if (m_eOutputLevel >= OL_Debug)
            cout << "cOutStream::cOutStream: bad=" << pStream->bad() << " fail=" << pStream->fail() << " eof=" << pStream->eof() << " good=" << pStream->good() << endl;
        bool bExists = pStream->good();
        delete pStream;
        if (bExists)
            throw cException ("Output file " + csOutStream + " already exists.\nTo allow overwrite you must specify the file name on the command line.");
    }

    // Initialize private data members
    m_pStream = new ofstream (csOutStream.data(), ios_base::trunc);
    if (!m_pStream)
        throw cException ("Unable to create stream object");
    if (m_eOutputLevel >= OL_Debug)
        cout << "cOutStream::cOutStream: bad=" << m_pStream->bad() << " fail=" << m_pStream->fail() << " eof=" << m_pStream->eof() << " good=" << m_pStream->good() << endl;
    if (m_pStream->fail()) {
        delete m_pStream;
        m_pStream = NULL;
        throw cException ("Unable to open output file \'" + csOutStream + "\'");
    }
    m_nLineCount = 0;
}

// Destructor
cOutStream::~cOutStream()
{
   if (m_pStream) {
      m_pStream->close();
      delete m_pStream;
   }
}

// ---------------------------------------------------------------------------
// Data processing
// ---------------------------------------------------------------------------
// Write a line
void cOutStream::WriteLine (const string cs)
{
    try {
        if (m_eOutputLevel == OL_Dump)
            cout << "cOutStream::WrtLine# " <<  m_nLineCount+1 << ".\'" << cs << "\'\n";
        *m_pStream << cs.data() << '\n';
        m_nLineCount++;
    } catch (...) {
        throw cException ("Write error in line # %d", m_nLineCount+1);
    }
    // cout << "bad=" << m_pStream->bad() << " fail=" << m_pStream->fail() << " eof=" << m_pStream->eof() << " good=" << m_pStream->good() << endl;
}

