// =============================================================================
// Part.h: Declarations of class cPart
// Filter application, (c) lars.staurset@statkart.no 2003
// Purpose: Handle a part, e.g. an attachment
// =============================================================================

#pragma once
#include "Typedefs.h"
#include "PartHeader.h"
#include "OutStream.h"

class cPart
{
    // =========================================================================
    // Public functions
    // =========================================================================
public:
    // ---------------------------------------------------------------------------
    // Class administration (construction, destruction, etc.)
    // ---------------------------------------------------------------------------
    cPart (
        const ContentType,      // Content-Type of message
        const OutputLevel,      // Output level, see Typedefs.h
        cOutStream *);          // Output stream
    ~cPart ();

    // ---------------------------------------------------------------------------
    // Data processing
    // ---------------------------------------------------------------------------
    // Process a line that belongs to a part
    // Success: Line is analyzed in context and stored, written to outstream, or discarded
    // Failure: Throws a cException on file error or format error
    bool ProcessLine (          // return true if this line terminates part???
        const string);              // Line to be processed

    // Is this part to be removed?
    bool GetRemoved() { return m_bRemoved; }

    // =========================================================================
    // Private functions
    // =========================================================================
private:

    // Analyze and prepare header when all lines have been read
    bool AnalyzeHeader();   // returns true if part was already removed

    // Do what's needed to remove this part of a report-type message
    // Success: Saves modified header and replaces body with standard text
    // Failure: Throws a cException on file error
    bool RemoveReportPart();    // returns true if part was already removed

    // Do what's needed to remove this attachment of a nonreport message
    // Success: Saves modified header and replaces body with standard text
    // Failure: Throws a cException on file error
    bool RemoveAttachment();    // returns true if attachment was already removed

    // =========================================================================
    // Private data members
    // =========================================================================
private:
    // ---------------------------------------------------------------------------
    // Members passed from client class
    // ---------------------------------------------------------------------------
    ContentType m_eContentType; // Content-Type
    OutputLevel m_eOutputLevel;    // Output level, see Typedefs.h
    cOutStream *m_pOutStream;   // Outstream object

    // ---------------------------------------------------------------------------
    // Members proper to this class
    // ---------------------------------------------------------------------------
    cPartHeader *m_pPartHeader; // Pointer to cPartHeader object
    bool m_bInBodyToBeRemoved;  // true if current line is in body of part to be removed
    bool m_bRemoved;            // true if this part is to be removed
};
