// =============================================================================
// PartHeader.h: Declarations of class cPartHeader
// Filter application, (c) lars.staurset@statkart.no 2003
// Purpose: Handle part headers
// =============================================================================

#pragma once
#include "Header.h"

class cPartHeader : public cHeader
{
    // =========================================================================
    // Public functions
    // =========================================================================
public:
    // ---------------------------------------------------------------------------
    // Class administration (construction, destruction, etc.)
    // ---------------------------------------------------------------------------
    cPartHeader (
        const bool,             // true if message header indicates report
        const OutputLevel);     // Output level, see Typedefs.h
    ~cPartHeader ();

    // ---------------------------------------------------------------------------
    // Data processing
    // ---------------------------------------------------------------------------

    // Analyze a header when all lines have been read
    // Success: Finds file name, Content-Type and other information
    // Failure: Throws a cException on missing information
    bool Analyze ();        // Returns true if part is unremovable

    // Get boundary string that separates parts of message
    string GetFilename() const { return m_sFilename; }

    // Get Content-Type
    string GetContentType() const { return m_sContentType; }

    // Prepare attachment header whose body is to be removed
    // Only to be called for removable attachments
    // Success: Set parameters to indicate removal
    // Failure: N/A
    bool PrepareAttachmentHeader ();   // returns true if attachment was already removed

    // Prepare report part header whose body is to be removed
    // Only to be called for removable part headers in a report context
    // Success: Set parameters to indicate removal
    // Failure: N/A
    bool PrepareReportPartHeader ();    // returns true if part was already removed

    // =========================================================================
    // Private functions
    // =========================================================================

    // Analyze one line of header after all lines are read
    // Success: Extracts possible information from line
    // Failure: N/A
    bool AnalyzeLine (      // returns true if line indicates that part should
                            // not be removed (depending on type and context)
        list<string>::iterator);    // Line to be analyzed

    // =========================================================================
    // Private data members
    // =========================================================================
private:
    // ---------------------------------------------------------------------------
    // Members passed from client class
    // ---------------------------------------------------------------------------
    bool m_bReport;                 // true if message type is report

    // ---------------------------------------------------------------------------
    // Members proper to this class
    // ---------------------------------------------------------------------------
    string m_sFilename;             // File name
    string m_sContentType;          // Contents of Content-Type field
    HeaderPosition m_hpContentType1;    // Pos of 1st interesting item in Content-Type
    HeaderPosition m_hpContentType2;    // Pos of 2nd interesting item in Content-Type
    HeaderPosition m_hpContentDisposition;  // Pos of interesting item in Content-Disposition
    HeaderPosition m_hpContentTransferEncoding; // Pos of interesting item in Content-Transfer-Encoding
};
